@@ -1,5 +1,6 @@
 
-package AWS::S3::Request::SetFileContents;
+package 
+AWS::S3::Request::SetFileContents;
 
 use VSO;
 use AWS::S3::HTTPRequest;
@@ -16,12 +17,14 @@ sub http_request
 {
   my $s = shift;
   
-  return AWS::S3::HTTPRequest->new(
+  my $req = AWS::S3::HTTPRequest->new(
     s3      => $s->s3,
     method  => 'PUT',
     path    => $s->_uri('') . $s->file->key,
     content => $s->file->contents,
   )->http_request;
+  $req->header('content-length' => length($req->content));
+  return $req;
 }# end http_request()
 
 1;# return true:
