@@ -1,9 +1,8 @@
 
-package AWS::S3::Response;
+package 
+AWS::S3::Response;
 
 use VSO;
 
-
-
 1;# return true:
 
